﻿using UnityEngine;
using System.Collections;

public class HUDController : MonoBehaviour 
{
	void Start() 
	{
		_mTimeElapsed = 0.0f;
		
		_mGemRectangle = new Rect[mNumGemsInLevel];
		_mGemCollected = new bool[mNumGemsInLevel];
		
		_mGemTexture = new Texture[4]; //Two gem state textures
		_mGemTexture[0] = Resources.Load("EmptyGem") as Texture; //Load in the texture for uncollected gem
		_mGemTexture[1] = Resources.Load("RedGem") as Texture; //Load in the texture for collected red gem
		_mGemTexture[2] = Resources.Load("GreenGem") as Texture; //Load in the texture for collected green gem
		_mGemTexture[3] = Resources.Load("BlueGem") as Texture; //Load in the texture for collected blue gem
		
		_mTimeRectangle = new Rect(Screen.width - 150, 4, 128, 32);
		_mTimeStyle = new GUIStyle();
		_mTimeStyle.normal.textColor = Color.black; //Make the text color black
		_mTimeStyle.fontStyle = FontStyle.Bold; //Make it bold too cause what the hell
		_mTimeStyle.alignment = TextAnchor.MiddleRight;
		_mTimeStyle.fontSize = 32;
		
		for (uint i = 0; i < mNumGemsInLevel; ++i)
		{
			_mGemRectangle[i] = new Rect(Screen.width - 50 * (i + 1), 32, 50, 36); //Layers them from the top right side of the screen
			_mGemCollected[i] = false; //Starts off not collected
		}
	}
	
	void OnGUI()
	{
		_mTimeText = "Time: " + (int) _mTimeElapsed; //The time is casted to an int to truncate the decmals
		GUI.Label(_mTimeRectangle, _mTimeText, _mTimeStyle); //Draw the time on screen
		
		for (uint i = 0; i < mNumGemsInLevel; ++i)
		{
			if (_mGemCollected[i] == false)
			{
				GUI.DrawTexture(_mGemRectangle[i], _mGemTexture[0]); //Draw the empty gem
			}
			else
			{
				GUI.DrawTexture(_mGemRectangle[i], _mGemTexture[i + 1]); //Draw the right colour
			}
		}
	}
	
	void Update() 
	{
		_mTimeElapsed += Time.deltaTime;
	}
	
	public void setGemCollected(int pIndex, bool pState) //Sets the state of that gem
	{
		_mGemCollected[pIndex] = pState;
		_mGemSounds[pIndex].Play();
	}
	
	public bool getGemCollected(uint pIndex) //Get the state of that gem
	{
		return _mGemCollected[pIndex];
	}
	
	public int mNumGemsInLevel = 1; //Number of gems in this level
	private Rect[] _mGemRectangle; //The rectangles for the text
	private bool[] _mGemCollected; //The parallel array for above to checks if the gem was collected
	private Texture[] _mGemTexture; //The texture for the gem. 0 is empty, 1 is full.
	
	public AudioSource[] _mGemSounds;
	
	private float _mTimeElapsed; //The time that have elapsed in the level	
	private Rect _mTimeRectangle; //The rectangle for the text
	private GUIStyle _mTimeStyle; //The style of the font text
	private string _mTimeText; //The actual text to display on the screen
}
