﻿using UnityEngine;
using System.Collections;

public class InteractableAttribute : MonoBehaviour 
{	
	void Start () 
	{
		_mPlayer = GameObject.Find("PLAYER"); //Get the player
		
		if (mPushable == true) //If it's pushable..
		{
			this.gameObject.AddComponent<Rigidbody>(); //Add a rigid body
			this.gameObject.GetComponent<Rigidbody>().constraints = RigidbodyConstraints.FreezePositionZ | RigidbodyConstraints.FreezeRotation;
		}
		
		
		_mToggled = false;
		mToggleDistance *= mToggleDistance; //Square it
		
		if (mDangerous == true || mCollectable == true || mCheckpoint == true) //Dangerous and collectable objects can be interacted with
		{
			this.gameObject.GetComponent<BoxCollider>().isTrigger = true; //We set this trigger to true first since cubes already have box colliders
			//this.gameObject.AddComponent<BoxCollider>(); //Add a new one to lock it in place
		}
		
		if (mLevelBoundary == true || mCheckpoint == true) //If it's a level boundary or checkpoint, we don't want to see it
		{
			this.renderer.enabled = false;
		}
	}
	
	void Update () 
	{
		if (mToggleable)
		{
			if (Input.GetKeyDown(KeyCode.X)) //If the X button was pressed
			{
				if ((_mPlayer.transform.position - this.transform.position).sqrMagnitude < mToggleDistance) //If we are within the distance
				{
					_mToggled = !_mToggled;
					Debug.Log (_mToggled);
				}
			}
		}
	}
	
	void OnTriggerEnter(Collider pObject)
	{
		if (pObject.tag == "PLAYER_FEET" || pObject.tag == "Player")
		{
			if (mDangerous == true) //If it's dangerous..
			{
				//if (renderer.enabled == true)
				{
					_mPlayer.GetComponent<PlayerController>().resetToCheckpoint();//Set the player back to the last checkpoint
				}
			}
			else if (mCollectable == true) //If it's collectable..
			{
				this.gameObject.transform.Translate(Vector3.up * 9001);
				//this.gameObject.SetActive(false);
				GameObject.Find("Main Camera").GetComponent<HUDController>().setGemCollected(mCollectableNumber, true);
			}
			else if (mCheckpoint == true) //If it's a checkpoint..
			{
				_mPlayer.GetComponent<PlayerController>().setCheckpoint(_mPlayer.transform.position);
				PlayerController.onWallLeft = false;
				PlayerController.onWallRight = false;
				PlayerController.onWall = false;
				
				this.gameObject.transform.Translate(Vector3.up * 9001);
			}
		}
	}
	
	bool getToggled()
	{
		return _mToggled;
	}
	
	public bool mPushable = false; //If enabled it means you can push it
	public bool mToggleable = false; //If enabled it means you can toggle it on or off
	public bool mDangerous = false; //If enabled in means it's dangerous
	public bool mCollectable = false; //If enabled it means you can collect it
	public bool mLevelBoundary = false; //If enabled it means you can't see it
	public bool mCheckpoint = false; //If enabled it means you can't see it and it will set the checkpoint of the player
	
	public int mToggleDistance = 2; //Two units
	public int mCollectableNumber = 0; //The gem number
	
	private GameObject _mPlayer; //The player
	private bool _mToggled; //Whether or not it is toggled
}
