﻿using UnityEngine;
using System.Collections;

/* Objects with this script attached will ONLY be activated once in the Shadow World */
// NOTE - this script duplicated the object to cast the in-game shadow, so a second object is NOT required
// NOTE - the color-world shadow of the invisible object can be turned off using the bool in the inspector

// Created by Alex Smith, January 24th, 2014

public class ObjectShadowProperties : MonoBehaviour
{

	// Use this for initialization
	void Start ()
	{
		hasSpawnedDuplicate = false;
	}
	
	// Update is called once per frame
	void Update ()
	{
		if(!isVisibleInColorWorld && castShadowInColorWorld && !hasSpawnedDuplicate)
		{
			// Spawns the clone object at the desired distance
			duplicateObject = (GameObject)Instantiate(gameObject, new Vector3(transform.position.x,transform.position.y,transform.position.z - duplicateObjectSpawnDistance), transform.rotation);

			ObjectShadowProperties script = duplicateObject.GetComponent<ObjectShadowProperties>();
			script.enabled = false;

			// Prevent multiple objects from being created
			hasSpawnedDuplicate = true;
		}
		else if((hasSpawnedDuplicate && isVisibleInColorWorld) || (hasSpawnedDuplicate && !castShadowInColorWorld))
		{
			Destroy(duplicateObject);
			duplicateObject = null;
			hasSpawnedDuplicate = false;
		}


		if(GameModeController.inShadowMode)
		{
			if(castShadowInShadowWorld)
			{
				renderer.enabled = true;				collider.enabled = true;
			}
			else
			{
				renderer.enabled = false;
			}

			if(isActiveInShadowWorld)
			{
				collider.enabled = true;
			}
			else
			{
				collider.enabled = false;
			}
		}
		else
		{
			if(isVisibleInColorWorld)
			{
				renderer.enabled = true;
				collider.enabled = true;
				renderer.castShadows = false;

				if(castShadowInColorWorld)
				{
					renderer.castShadows = true;
				}

			}
			else
			{
				renderer.enabled = false;
				collider.enabled = false;

				if(castShadowInColorWorld && hasSpawnedDuplicate)
				{
					duplicateObject.renderer.enabled = true;
				}
				else if(!castShadowInColorWorld && hasSpawnedDuplicate)
				{
					duplicateObject.renderer.enabled = false;
				}
			}
		}

		// Possible states:
		// Visible in color world, shadow in color world, shadow in shadow world, active in shadow world
	}

	public bool isActiveInShadowWorld;
	public bool isVisibleInColorWorld;
	public bool castShadowInColorWorld;
	public bool castShadowInShadowWorld;

	public float duplicateObjectSpawnDistance;
	private bool hasSpawnedDuplicate;
	private GameObject duplicateObject;
}
