using UnityEngine;
using System.Collections;


public class PlayerController : MonoBehaviour
{

	public static Vector3 playerPosition;						// Position of the player in the world (for public access)
	
	public float runSpeed;										// The speed of the player (running left/right)
	public float jumpStrength;									// The strength of the player's jump
	public float acceleration;									// Modifies how fast the player "speeds up"
	public Vector2 maxVelocity;									// Caps all of the player's velocities
	public float friction;
	
	public static bool onWall = false;							// Is the player on the wall?
	public static bool onWallLeft = false;
	public static bool onWallRight = false;
	public static bool onGround = false;						// Is the player on the ground? (ground && wall = corner)
	public bool canJump = false;								// Can the player jump?
	public bool jumping = false;							// Is the player jumping? (not the same as falling!)

	public int direction = 1;									// Defines which direction the player should be rotated to

	private Vector3 _mCheckpointPosition;						//The checkpoint the player will respawn at
	
	
	// Use this for initialization
	void Start ()
	{
		_mCheckpointPosition = this.transform.position; //Starts off at the beginning
	}
	
	// Update is called once per frame
	void Update ()
	{
		if(jumping && onGround)
		{
			jumping = false;
		}
		if(!jumping)
		{
			canJump = true;
		}

		// Save the player's position to the static variable
		playerPosition = transform.position;

		// Grab the current velocity (will be used for max velocity && setting new ones)
		Vector3 finalVelocity = rigidbody.velocity;

		// Set the player's direction (rotate model)
		if(direction == 1)
		{
			transform.rotation = Quaternion.Euler(transform.rotation.eulerAngles.x,0.0f,transform.rotation.eulerAngles.z);
		}
		else
		{
			transform.rotation = Quaternion.Euler(transform.rotation.eulerAngles.x,180.0f,transform.rotation.eulerAngles.z);
		}


// RUN LEFT	
		if(Input.GetKey(KeyCode.LeftArrow) && !onWallLeft)
		{
			//Debug.Log ("OY");
			finalVelocity.x += -runSpeed * acceleration * Time.deltaTime;
			direction = -1;
		}

// RUN RIGHT		
		else if(Input.GetKey(KeyCode.RightArrow) && !onWallRight)
		{
			//Debug.Log ("YO");
			finalVelocity.x += runSpeed * acceleration * Time.deltaTime;
			direction = 1;
		}

// JUMPING
		// If the player hits spacebar || the up arrow
		if((Input.GetKeyDown(KeyCode.Space) || Input.GetKeyDown(KeyCode.UpArrow)))
		{
			// If the player is on the ground and is ready to jump
			if(canJump && onGround)
			{
				// Set the verticle (+y) velocity (no acceleration here)
				finalVelocity.y = jumpStrength;
				canJump = false;
				onGround = false;
				jumping = true;
			}
		}
		
// VELOCITY CHECKS
		// Check that all velocities are within the limits set (as they can alter drastically based on physics/gravity/other factors)
		if(finalVelocity.x > friction)
		{
			finalVelocity.x -= friction;
		}
		if(finalVelocity.x < -friction)
		{
			finalVelocity.x += friction;
		}
		if(finalVelocity.x > maxVelocity.x)
		{
			finalVelocity.x = maxVelocity.x;
		}
		else if(finalVelocity.x < -maxVelocity.x)
		{
			finalVelocity.x = -maxVelocity.x;
		}
		if(finalVelocity.y < -maxVelocity.y)
		{
			finalVelocity.y = -maxVelocity.y;
		}
		if(finalVelocity.y > maxVelocity.y)
		{
			finalVelocity.y = maxVelocity.y;
		}
		
		// Apply the final velocity after all limits have been enforced
		rigidbody.velocity = finalVelocity;
	}

	void OnCollisionEnter(Collision collision)
	{

	}

	void OnCollisionExit(Collision collision)
	{

	}

	public void setCheckpoint(Vector3 pVec)
	{
		_mCheckpointPosition = pVec;
	}
	
	public Vector3 getCheckpoint()
	{
		return _mCheckpointPosition;
	}
	
	public void resetToCheckpoint()
	{
		this.transform.position = _mCheckpointPosition;
	}
}
