﻿/*
 Zach Stock - 2014
 Scene Transition Script
 Script fades scene in from black and fades screen out to black when a win condition is met

 To use, attach script to something that will not be deleted during the course of the level (Main Camera/Empty Game Object)
 Script automatically fades scene in from black. To fade out, set "win" to true when your win condition is met*/

using UnityEngine;
using System.Collections;

public class SceneTransition : MonoBehaviour {

	GameObject transitionPlane;
	Shader shader1;
	public float transitionDuration;
	float t1;
	float t2;
	bool opened;
	bool closed;
	public int sceneToLoad;
	public bool win;

	// Use this for initialization
	void Start () {
		shader1 = Shader.Find ("Transparent/Diffuse");

		transitionPlane = GameObject.CreatePrimitive(PrimitiveType.Plane);//Spawn plane
		transitionPlane.renderer.material.shader = shader1;//Change shader from default to Transparent/Diffuse

		transitionPlane.transform.localScale = (new Vector3(3.0f, 1.0f, 2.0f));//Scale plane up
		transitionPlane.transform.position = (new Vector3(0.0f, 1.0f, this.transform.position.z+0.31f));//Move plane up to cover screen
		transitionPlane.renderer.material.color = (new Vector4(0.0f,0.0f,0.0f,1.0f));//Plane starts black
		transitionPlane.transform.Rotate(Vector3.right*270);//Rotate plane to face camera
		transitionPlane.transform.parent = transform;//Attach plane to camera

		opened = false;
		closed = false;
		t1=0;
		t2=0;
		win = false;
	}
	
	// Update is called once per frame
	void Update () {
		if (!opened)
		{
			FadeIn ();
		}
		if (t1>1)
		{
			opened = true;
			transitionPlane.SetActive (false);
		}

		if (opened && closed)
		{
			FadeOut ();
		}
		if (t2>1)//scene transition
		{
			Application.LoadLevel (sceneToLoad);
		}

		if (win)
		{
			transitionPlane.SetActive (true);
			closed = true;
		}
	}

	void FadeIn ()
	{
		transitionPlane.renderer.material.color = Color.Lerp(new Vector4 (0.0f,0.0f,0.0f,1.0f),new Vector4(0.0f,0.0f,0.0f,0.0f),t1);
		t1 += Time.deltaTime/transitionDuration;
	}

	void FadeOut ()
	{
		transitionPlane.renderer.material.color = Color.Lerp(new Vector4 (0.0f,0.0f,0.0f,0.0f),new Vector4(0.0f,0.0f,0.0f,1.0f),t2);
		t2 += Time.deltaTime/transitionDuration;
	}
}
